@@ -1,11 +1,10 @@
 import os
-class Anagram(object):
 
+class Anagram(object):
     
     __author__ = 'Michael S. Russell'
     __email__ = 'michael.r2014@yahoo.co.uk'
-    __version__ = '1.0.8'
-    
+    __version__ = '1.0.9'
     
     def __init__(self):
         
@@ -14,11 +13,11 @@ class Anagram(object):
         self.res = {}
         self.sentence = ""
         self.json = {"anagram": [], "non-anagram": []}
-	self.path = os.getcwd()
+        self.path = os.getcwd()
     
     def init_app(self):
         
-        with open(self.path +"\english.txt", "r") as r:
+        with open(self.path + "\\english.txt", "r") as r:
             words = r.read().replace("\n", ",").split(",")
             
         self.words = words
@@ -110,45 +109,3 @@ class Anagram(object):
         
         return data
     
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
\ No newline at end of file
